import time
import threading
from flask import Flask, jsonify

__version__ = '0.0.2'


class SingletonMixin(object):
    __singleton_lock = threading.Lock()
    __singleton_instance = None

    @classmethod
    def instance(cls):
        if not cls.__singleton_instance:
            with cls.__singleton_lock:
                if not cls.__singleton_instance:
                    cls.__singleton_instance = cls()
        return cls.__singleton_instance


class Counter(SingletonMixin):
    counter = 0
    __lock = threading.Lock()

    def incr(self):
        with self.__lock:
            self.counter += 1

        return self.counter


counter = Counter()


def gen_guid(shard_id=1):
    incr = counter.incr()

    guid = (int(time.time() * 1000) << (64 - 41))
    guid |= (shard_id << (64 - 41 - 13))
    guid |= incr % 1024

    return guid


app = Flask(__name__)


@app.route('/')
def index():
    return 'guid server.'


@app.route('/guid')
@app.route('/guid/<int:shard_id>')
def guid(shard_id=1):
    return jsonify({'shard_id': shard_id, 'guid': gen_guid(shard_id)})



#!/usr/bin/env python
from flask.ext.script import Manager, Server
from flask_script.commands import ShowUrls, Clean
from fluffy_id import app

manager = Manager(app)
server = Server(host="0.0.0.0", port=7001)
manager.add_command("runserver", server)


@manager.shell
def make_shell_context():
    """
    Creates a python REPL with several default imports
    in the context of the app
    """
    return dict(app=app)


def main():
    manager.add_command("clean", Clean())
    manager.add_command("show_urls", ShowUrls())
    manager.run()


if __name__ == "__main__":
    main()



import os
import re
from setuptools import setup


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


def find_version(fname):
    '''Attempts to find the version number in the file names fname.
    Raises RuntimeError if not found.
    '''
    version = ''
    with open(fname, 'r') as fp:
        reg = re.compile(r'__version__ = [\'"]([^\'"]*)[\'"]')
        for line in fp:
            m = reg.match(line)
            if m:
                version = m.group(1)
                break
    if not version:
        raise RuntimeError('Cannot find version information')
    return version


__version__ = find_version(os.path.join("fluffy_id", "__init__.py"))

setup(
    name='fluffy_id',
    version=__version__,
    long_description=read('README.md'),
    packages=['fluffy_id'],
    url='http://github.com/yoophi/fluffy-id',
    license='MIT License',
    author='Pyunghyuk Yoo',
    author_email='yoophi@gmail.com',
    description='GUID Generator',
    include_package_data=True,
    zip_safe=False,
    entry_points={
        'console_scripts': [
            "fluffy_id = fluffy_id.runner:main"
        ]
    },
    install_requires=[
        'Flask==0.10.1',
        'Flask-Script',
    ],
    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
